@@ -1,4 +1,4 @@
-// 'use strict'; does not work, breaks directory selection form
+﻿// 'use strict'; does not work, breaks directory selection form
 
 var GAccountDlgInitialized=false;
     GButtonIsStopScheduler=null; // button caption not set yet
@@ -129,13 +129,15 @@ var GridDataAdapter = new $.jqx.dataAdapter(GridSource,
   loadComplete:
      function (data)
      {
+// Keep Literals
        if (GisSyncoveryDebug) console.log("Profile List loaded");
        if (!GAddRowButtonFocusedOnce)
           FocusAddRowButton();
      },
   loadError: function (xhr, status, error) {
     if (GisSyncoveryDebug) console.log("Profile list loading error:", error);
-    alert("Profile list loading error:" + error);
+// Convert Literals
+    alert(txtProfileListLoadingError + error);
   },
                 
   beforeSend: function (xhr) {
@@ -192,7 +194,7 @@ function RenameProfile(ADuplicate)
 
    $("#RenameProfileDlg_div").html(RenameProfileHTML);
    $('#jqxRenameProfileDlg').jqxWindow({ maxWidth: 640,  width:640, maxHeight:80, height:80, autoOpen: false, isModal: true,
-     theme: GTheme, animationType: 'slide' });
+     theme: GTheme, animationType: 'none' });
 
    $("#inpt_ProfileName").jqxInput({width: 400,  height: 25, value: SelectedProfile});
 
@@ -220,7 +222,10 @@ function RenameProfile(ADuplicate)
         }
         else
         {
-           alert("Profile was not " + (ADuplicate ? "duplicated" : "renamed") + ": " + data);
+           if (ADuplicate)
+              alert(txtProfileWasNotDuplicated + ": " + data);
+           else
+              alert(txtProfileWasNotRenamed + ": " + data);
         }
       });
 
@@ -241,7 +246,7 @@ function ImportProfiles()
 {
    $("#ImportProfilesDlg_div").html(ImportProfilesHTML);
    $('#jqxImportProfilesDlg').jqxWindow({ maxWidth: 580,  width:400, maxHeight:800, height:400, autoOpen: false, isModal: true,
-           theme: GTheme, animationType: 'slide' });
+           theme: GTheme, animationType: 'none' });
 
    $('#jqxFileUpload').jqxFileUpload({ width: 300, uploadUrl: 'profileimport.php?token='+GClientToken, fileInputName: 'fileToUpload'});
 
@@ -261,13 +266,13 @@ function ImportBinCompResults()
 
    if (Lprofname == "")
    {
-      alert("Please choose a profile to import the binary comparison results into.");
+      alert(txtPleaseChooseAProfileToImportThe);
       return;
    }
 
    $("#ImportBinCompResultsDlg_div").html(ImportBinCompResultsHTML);
    $('#jqxImportBinCompResultsDlg').jqxWindow({ maxWidth: 580,  width:400, maxHeight:800, height:400, autoOpen: false, isModal: true,
-           theme: GTheme, animationType: 'slide' });
+           theme: GTheme, animationType: 'none' });
 
    $('#jqxFileUploadBinComp').jqxFileUpload({ width: 300, uploadUrl: 'bincompresultsimport.php?token='+GClientToken+
                                          '&profilename='+Lprofname,
@@ -305,7 +310,7 @@ function checkeventsuccess(data)
     {
        if (Lalert.startsWith("OPENURL:"))
        {
-          alert("Please enable pop-ups, we will now try to open a new tab or window");
+          alert(txtPleaseEnablePopUpsWeWillNow);
           window.open(Lalert.substring(8,10000));
        }
        else
@@ -375,15 +380,15 @@ function checkeventsuccess(data)
     //   Lmsg = 'data.profiles=undefined';
 
     if ((Lmsg==undefined) || (Lmsg=="undefined"))
-       Lmsg = "Logged out - please refresh page to log in";
+       Lmsg = txtLoggedOutPleaseRefreshPageToLog;
 
     // console.log('Setting title grid');
     $("#titlegrid").jqxGrid(
     {
        columns: [
-         { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgBR+GLicenseMsg, width: cTitleGridCol1Width },
-         { text: "<b>"+Lmsg+"</b>", width: cTitleGridCol2Width },
-         { text: Lsrvtime, width: cTitleGridCol3Width, align: 'center' }
+         { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgFirstLine },
+         { text: "<b>"+Lmsg+"</b>"},
+         { text: Lsrvtime, align: 'center' }
          ]
     });
 
@@ -395,15 +400,15 @@ function checkeventsuccess(data)
 	     {
 	        if (GisSyncoveryDebug) console.log('Setting scheduler button caption to Stop');
 	        var $btn = $('#start_scheduler_button');
-	        $btn.jqxButton('val', 'Stop');
-	        $btn.attr('title', 'Stop Scheduler');
+	        $btn.jqxButton('val', txtStop);
+	        $btn.attr('title', txtStopScheduler);
 	     }
 	     else
 	     {
 	        if (GisSyncoveryDebug) console.log('Setting scheduler button caption to Start');
 	        var $btn = $('#start_scheduler_button');
-	        $btn.jqxButton('val', 'Start')
-	        $btn.attr('title', 'Start Scheduler');
+	        $btn.jqxButton('val', txtStart)
+	        $btn.attr('title', txtStartScheduler);
 	     }
       GButtonIsStopScheduler=isrunning;
     }
@@ -415,7 +420,7 @@ function checkeventerror(jqXHR,textStatus,errorThrown)
    $("#titlegrid").jqxGrid(
    {
       columns: [
-        { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgBR+GLicenseMsg, width: cTitleGridCol1Width },
+        { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgFirstLine, width: cTitleGridCol1Width },
         { text: "<b>Syncovery WebServer unavailable: "+textStatus+' '+errorThrown+"</b>", width: cTitleGridCol2Width },
         { text: "", width: cTitleGridCol3Width }
         ]
@@ -428,7 +433,7 @@ function showstatusmessage(textStatus)
    $("#titlegrid").jqxGrid(
    {
       columns: [
-        { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgBR+GLicenseMsg, width: cTitleGridCol1Width },
+        { text: "&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgFirstLine, width: cTitleGridCol1Width },
         { text: textStatus, width: cTitleGridCol2Width },
         { text: "", width: cTitleGridCol3Width }
         ]
@@ -516,10 +521,10 @@ InitMainForm = function()
 
   var MainFormHTML = MainFormHTMLPart1;
 
-  if (GLicenseMsg.substring(0,12)=='Limited Free')
+  if (GShowLimitedFree)
      MainFormHTML = MainFormHTML+
                     "<div><p style='font-family: Verdana,Arial,sans-serif;font-size: 13px;margin-left: 8px;margin-top: 8px;margin-bottom: 8px;'>"+
-                    "Please see <a HREF='https://www.syncovery.com/freelinuxedition/' target='_blank' rel='noopener'>our web site</a> for details about licensing Syncovery and the Limited Free Edition."+
+                    GLicenseMsgSecondLine+txtSeeWebSiteAboutFreeEdition+
                     "</p></div>";
 
   MainFormHTML = MainFormHTML + MainFormHTMLPart2;
@@ -527,71 +532,70 @@ InitMainForm = function()
   $("#MainForm_div").html(MainFormHTML);
 
   // initialize jqxGrid
-  var contextMenu = $("#jqxMenu").jqxMenu({width: 220, height: GContextMenuHeight, autoOpenPopup: false, mode: 'popup'});
+  var contextMenu = $("#jqxMenu").jqxMenu({width: 300, height: GContextMenuHeight, autoOpenPopup: false, mode: 'popup'});
 
   // open the context menu when the user presses the mouse right button.
 
-
   $('#jqxMenu').on('itemclick', function (event)
   {
     // get the clicked LI element.
-    if ($(event.target).text() == "Edit Profile")
+    if ($(event.target).text() == txtEditProfile)
     {
         setTimeout(EditSelectedProfile, 100);
     }
-    else if ($(event.target).text() == "Add New Profile")
+    else if ($(event.target).text() == txtAddNew)
     {
         AddProfile();
     }
-    else if ($(event.target).text() == "Delete Profile")
+    else if ($(event.target).text() == txtDeleteProfile)
     {
        DeleteProfile();
     }
-    else if ($(event.target).text() == "Rename Profile")
+    else if ($(event.target).text() == txtRenameProfile)
     {
        RenameProfile(false);
     }
-    else if ($(event.target).text() == "Duplicate Profile")
+    else if ($(event.target).text() == txtDuplicateProfile)
     {
        RenameProfile(true);
     }
-    else if ($(event.target).text() == "Enable Profile")
+    else if ($(event.target).text() == txtEnableProfile)
     {
        EnableDisableProfile(true);
     }
-    else if ($(event.target).text() == "Disable Profile")
+    else if ($(event.target).text() == txtDisableProfile)
     {
        EnableDisableProfile(false);
     }
-    else if ($(event.target).text() == "Resume Profile")
+    else if ($(event.target).text() == txtResumeProfile)
     {
        PauseResumeProfile(true);
     }
-    else if ($(event.target).text() == "Pause Profile")
+    else if ($(event.target).text() == txtPauseProfile)
     {
        PauseResumeProfile(false);
     }
-    else if ($(event.target).text() == "Lock Profile Settings")
+    else if ($(event.target).text() == txtLockProfile)
     {
        LockProfile(true);
     }
-    else if ($(event.target).text() == "Unlock Profile Settings")
+    else if ($(event.target).text() == txtUnlockProfile)
     {
        LockProfile(false);
     }
-    else if ($(event.target).text() == "Run Unattended")
+    else if ($(event.target).text() == txtRunUnattended)
     {
        RunSelectedProfile(false);
     }
-    else if ($(event.target).text() == "Run With Preview")
+    else if ($(event.target).text() == txtRunWithPreview)
     {
        RunSelectedProfile(true);
     }
-    else if ($(event.target).text() == "Stop Profile")
+    else if ($(event.target).text() == txtStopProfile)
     {
        StopSelectedProfile();
     }
-    else if ($(event.target).text() == "Diagnose Activity")
+    else if ($(event.target).text() == txtDiagnoseActivity)
     {
        DiagnoseActivity();
     }
@@ -599,30 +603,30 @@ InitMainForm = function()
     {
        DumpMemoryUsage();
     }
-    else if ($(event.target).text() == "Show Detailed Status")
+    else if ($(event.target).text() == txtShowDetailed)
     {
        ShowDetailedStatus();
     }
-    else if ($(event.target).text() == "Import Profiles")
+    else if ($(event.target).text() == txtImportProfiles)
     {
        ImportProfiles();
     }
-    else if ($(event.target).text() == "Import Binary Comparison Results From Log")
+    else if ($(event.target).text() == txtImportBinaryComparisonResultsFrom)
     {
        ImportBinCompResults();
     }
-    else if ($(event.target).text() == "Export Profile")
+    else if ($(event.target).text() == txtExportProfile)
     {
        ExportProfile();
     }
-    else if ($(event.target).text() == "Export All Profiles")
+    else if ($(event.target).text() == txtExportAll)
     {
        ExportProfiles();
     }
-    else if ($(event.target).text() == "Terminate Process")
+    else if ($(event.target).text() == txtTerminateProcess)
     {
        if (GisSyncoveryWindows)
-          alert('Terminating from web GUI not supported.');
+          alert(txtTerminatingFromWebGuiNotSupported);
        else
           TerminateProcess();
     }
@@ -644,7 +648,7 @@ InitMainForm = function()
 	   if (rec.isLocked) icons.push('🔒');
 
     var txtcomment="";
-
+// Keep Literals
     if (rec.Comment && (rec.Comment>""))
     {
 	      icons.push('ℹ️');
@@ -694,14 +698,14 @@ InitMainForm = function()
       showemptyrow: false,
       theme: GTheme,
       columns: [
-        { text: "&nbsp;&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgBR+GLicenseMsg, width: cTitleGridCol1Width },
+        { text: "&nbsp;&nbsp;<b>"+GSyncoveryTitle+"</b>"+GLicenseMsgFirstLine, width: cTitleGridCol1Width },
         { text: '', width: cTitleGridCol2Width }
       ]
   });
 
   var G_ShedIdleTimeAfterStartupCb = true;
-
-  const LastUsedComboSource=["Any","1 Day","2 Days","3 Days","1 Week","2 Weeks","1 Month","3 Months","6 Months","1 Year","2 Years","3 Years"];
+// Convert Literals
+  const LastUsedComboSource=[txtAllTime,txt1Day,txt2Days,txt3Days,txt1Week,txt2Weeks,txt1Month,txt3Months,txt6Months,txt1Year,txt2Years,txt3Years];
 
   $("#jqxgrid").jqxGrid(
   {
@@ -726,27 +730,33 @@ InitMainForm = function()
 
     rendertoolbar: function (toolbar)
     {
+      const stopwidth=measureDialogStringWidth(txtStop);
+      const startwidth=measureDialogStringWidth(txtStart);
+      // console.log("in rendertoolbar: txtStop="+txtStop+",w=" + stopwidth + "; txtStart="+txtStart+",w=" + startwidth);
       var container = $(
         '<table class="toolrow" id="toolbarTable"><tr><td>'+
-        '<button style="margin-left: 10px;" id="addrowbutton" type="button" title="Add New Profile"></button>'+
-        '<button style="margin-left: 10px;" id="updaterowbutton" type="button" title="Edit Profile"></button>'+
-        '<button style="margin-left: 10px;" id="renamebutton" type="button" title="Rename Profile"></button>'+
-        '<button style="margin-left: 10px;" id="deletebutton" type="button" title="Delete Profile"></button>'+
-        '<button style="margin-left: 10px;" id="run_selected_profile_button" type="button" title="Run Profile Unattended"></button>'+
-        '<button style="margin-left: 10px;" id="run_attended_button" type="button" title="Run Profile With Preview"></button>'+
-        '<button style="margin-left: 10px;" id="show_status_button" type="button" title="Show Detailed Status"></button>'+
-        '<button style="margin-left: 10px;" id="stop_selected_profile_button" type="button" title="Stop Profile"></button>'+
-        '<button style="margin-left: 10px;" id="program_settings_button" type="button" title="Program Settings"></button>'+
-        '<button style="margin-left: 10px;" id="account_manager_button" type="button" title="Account Manager"></button>'+
-        '<button style="margin-left: 10px;" id="log_files_button" type="button" title="Log Files"></button>'+
-        '<button style="margin-left: 10px;" id="start_scheduler_button" type="button" value="Stop" title="Start or Stop Scheduler"></button>'+
-        '<button style="margin-left: 10px;" id="refresh_grid_button" type="button" title="Refresh"></button>'+
-        '<button style="margin-left: 10px;" id="logout_button" type="button" title="Logout"></button>'+
-        '<button style="margin-left: 10px;" id="help_button" type="button" title="Help"></button>'+
-        '&nbsp;&nbsp;&nbsp;&nbsp;<label id="lbl_Filter" for="inpt_Filter">Filter:</label> <input type="text" aria-labelledby="lbl_Filter" id="inpt_Filter"/>'+
-        '</td><td>&nbsp;&nbsp;&nbsp;&nbsp;Last Used Within:&nbsp;&nbsp;'+
+        '<button style="margin-left: 10px;" id="addrowbutton" type="button" title="'+txtAddNew+'"></button>'+
+        '<button style="margin-left: 10px;" id="updaterowbutton" type="button" title="'+txtEditProfile+'"></button>'+
+        '<button style="margin-left: 10px;" id="renamebutton" type="button" title="'+txtRenameProfile+'"></button>'+
+        '<button style="margin-left: 10px;" id="deletebutton" type="button" title="'+txtDeleteProfile+'"></button>'+
+        '<button style="margin-left: 10px;" id="run_selected_profile_button" type="button" title="'+txtRunProfileUnattended+'"></button>'+
+        '<button style="margin-left: 10px;" id="run_attended_button" type="button" title="'+txtRunProfileWithPreview+'"></button>'+
+        '<button style="margin-left: 10px;" id="show_status_button" type="button" title="'+txtShowDetailedStatus+'"></button>'+
+        '<button style="margin-left: 10px;" id="stop_selected_profile_button" type="button" title="'+txtStopProfile+'"></button>'+
+        '<button style="margin-left: 10px;" id="program_settings_button" type="button" title="'+txtProgramSettings+'"></button>'+
+        '<button style="margin-left: 10px;" id="account_manager_button" type="button" title="'+txtAccountManager+'"></button>'+
+        '<button style="margin-left: 10px;" id="log_files_button" type="button" title="'+txtLogFiles+'"></button>'+
+        '<button style="margin-left: 10px;" id="start_scheduler_button" type="button" value="'+
+                   (stopwidth>startwidth ? txtStop : txtStart)+
+                   '" title="'+txtStartorStopScheduler+'"></button>'+
+        '<button style="margin-left: 10px;" id="refresh_grid_button" type="button" title="'+txtRefresh+'"></button>'+
+        '<button style="margin-left: 10px;" id="logout_button" type="button" title="'+txtLogout+'"></button>'+
+        '<button style="margin-left: 10px;" id="help_button" type="button" title="'+txtHelp+'"></button>'+
+        '<button style="margin-left: 10px;" id="language_button" type="button" title="'+txtLanguage+'"></button>'+
+        '&nbsp;&nbsp;&nbsp;&nbsp;<label id="lbl_Filter" for="inpt_Filter">'+txtFilter+':</label> <input type="text" aria-labelledby="lbl_Filter" id="inpt_Filter"/>'+
+        '</td><td>&nbsp;&nbsp;&nbsp;&nbsp;'+txtLastUsedWithin+':&nbsp;&nbsp;'+
         '</td><td><span style="display:inline-block;" id ="jqxLastUsedCombo"></span>'+
-        '</td><td>&nbsp;&nbsp;</td><td><div id="jqxShowScheduledCB" style="margin-left: 10px; display:inline;">Show Scheduled Profiles Only</div></td>'+
+        '</td><td>&nbsp;&nbsp;</td><td><div id="jqxShowScheduledCB" style="margin-left: 10px; display:inline;">'+txtShowScheduledProfilesOnly+'</div></td>'+
         '</tr></table>');
                     
       toolbar.append(container);
@@ -794,17 +804,17 @@ InitMainForm = function()
       $("#log_files_button").jqxButton({height: GIconBtnHeight, width: GIconBtnWidth,imgSrc:"images/11.LogFiles48.png",imgWidth:24,imgHeight:24,imgPosition:"center"});
       $("#log_files_button").on('click', LogFiles);
 
-      $("#start_scheduler_button").jqxButton({height: GIconBtnHeight, width: GBtnWidth,imgSrc:"images/Scheduler48m.png",imgWidth:27,imgHeight:24,imgPosition:"left",textPosition: "left",textImageRelation: "imageBeforeText"});
+      $("#start_scheduler_button").jqxButton({height: GIconBtnHeight, imgSrc:"images/Scheduler48m.png",imgWidth:27,imgHeight:24,imgPosition:"left",textPosition: "left",textImageRelation: "imageBeforeText"});
       $("#start_scheduler_button").on('click', function ()
       {
         const label = $('#start_scheduler_button').text().trim();
 
         if (GisSyncoveryDebug) console.log("Scheduler button: "+label);
-        if (label === 'Start' )
+        if (label === txtStart )
         {
            StartScheduler();
         }
-        else if (label === 'Stop')
+        else if (label === txtStop)
         {
            StopScheduler();
         }
@@ -819,16 +829,18 @@ InitMainForm = function()
       $("#help_button").jqxButton({height: GIconBtnHeight, width: GIconBtnWidth,imgSrc:"images/help48.png",imgWidth:24,imgHeight:24,imgPosition:"center"});
       $("#help_button").on('click', ShowHelp);
 
+      $("#language_button").jqxButton({height: GIconBtnHeight, width: GIconBtnWidth,imgSrc:"images/language48.png",imgWidth:24,imgHeight:24,imgPosition:"center"});
+      $("#language_button").on('click', ChooseLanguage);
+
       $("#inpt_Filter").jqxInput({width: 100,  height: 25});
       $("#inpt_Filter").on('change', RefreshGrid);
 
-		    $("#jqxLastUsedCombo").jqxDropDownList({
-		      source: LastUsedComboSource,
-		      selectedIndex: 0,
-		      width: 80,
-		      dropDownWidth: 80,
-		      dropDownHeight: 400,
-		      height: 25});
+      CreateDropDownList("#jqxLastUsedCombo",
+                 LastUsedComboSource,
+                 0, // selectedIndex
+                 100, // default width
+                 400, // dropDownHeight
+                 25); // height
 
       $("#jqxShowScheduledCB").jqxCheckBox({width: 50,  height: 25});
       $("#jqxShowScheduledCB").on('change', RefreshGrid);
@@ -868,13 +880,13 @@ InitMainForm = function()
   columns: [
       { text: ' ', datafield: 'id', width: 12, cellsrenderer: imagerenderer },
 //            { text: 'Group', datafield: 'Group', width: 225 },
-      { text: 'Profile Name', datafield: 'HTMLName', width: 225 /*, cellsrenderer: namerenderer */ },
-      { text: 'Left-Hand Path', datafield: 'LeftPath', width: 320 },
-      { text: 'Dir.', datafield: 'direction', width: 40, cellsrenderer: directionrenderer, align: "center", cellsalign: "center" },
-      { text: 'Right-Hand Path', datafield: 'RightPath', width: 320 },
-      { text: 'Last Result or Progress', datafield: 'Progress', width: 410 },
-      { text: 'Last Run', datafield: 'LastRun', width: 179 },
-      { text: 'Next Run', datafield: 'NextRun', width: 179 }
+      { text: txtProfileName, datafield: 'HTMLName', width: 225 /*, cellsrenderer: namerenderer */ },
+      { text: txtLeftHand, datafield: 'LeftPath', width: 320 },
+      { text: txtDir, datafield: 'direction', width: 40, cellsrenderer: directionrenderer, align: "center", cellsalign: "center" },
+      { text: txtRightHand, datafield: 'RightPath', width: 320 },
+      { text: txtLastResultOr, datafield: 'Progress', width: 410 },
+      { text: txtLastRun2, datafield: 'LastRun', width: 179 },
+      { text: txtNextRun, datafield: 'NextRun', width: 179 }
      ]
 //        groupable: true,
 //        groups: ['Group']
@@ -931,20 +943,20 @@ InitMainForm = function()
 
  function EditSelectedProfile()
  {
-      showstatusmessage("Opening profile");
+      showstatusmessage(txtOpeningProfile);
       var selectedRow = $('#jqxgrid').jqxGrid('getselectedrowindex');
       if (selectedRow == -1)
       {
-         showstatusmessage("No profile selected");
-         alert("No profile selected");
+         showstatusmessage(txtNoProfile);
+         alert(txtNoProfile);
          return;
       }
 
        var SelectedRow = $('#jqxgrid').jqxGrid('getrowdata', selectedRow);
        if (!SelectedRow)
        {
-          showstatusmessage("No row selected");
-          alert("No row selected");
+          showstatusmessage(txtNoRow);
+          alert(txtNoRow);
           return;
        }
        var SelectedProfile = SelectedRow.Name;
@@ -957,7 +969,7 @@ InitMainForm = function()
        var json = JSON.stringify(sendparams);
        ProfileSource.url = "single_profile.php?qry=" +encodeURIComponent(json);
 
-       showstatusmessage("Loading profile");
+       showstatusmessage(txtLoadingProfile);
        var ProfileDataAdapter = new $.jqx.dataAdapter(ProfileSource,
         { loadComplete: function ()
           {
@@ -966,31 +978,31 @@ InitMainForm = function()
             {
                 $('#jqxLoader').jqxLoader('close');
                 window.location = '/index.html';
-                showstatusmessage("Loading error: session timeout");
-                alert("Loading error: session timeout");
+                showstatusmessage(txtLoadingErrorSession);
+                alert(txtLoadingErrorSession);
                 return;
             }
             else if (ProfileDataAdapter.xhr.responseText == '{"error":"session_busy"}')
             {
                 $('#jqxLoader').jqxLoader('close');
                 window.location = '/post_session_busy.php';
-                showstatusmessage("Loading error: session busy");
-                alert("Loading error: session busy");
+                showstatusmessage(txtLoadingErrorSession2);
+                alert(txtLoadingErrorSession2);
                 return;
             }
             else
             if (ProfileDataAdapter.xhr.responseText == '{"error":"profile_locked"}')
             {
                 $('#jqxLoader').jqxLoader('close');
-                showstatusmessage("Loading error: profile locked");
-                alert("Cannot edit - profile is locked.");
+                showstatusmessage(txtLoadingErrorProfile);
+                alert(txtCannotEditProfileIsLocked);
                 return;
             }
             else
             if (ProfileDataAdapter.xhr.responseText.substring(0,8) == '{"error"')
             {
                $('#jqxLoader').jqxLoader('close');
-               showstatusmessage("Loading error: " + ProfileDataAdapter.xhr.responseText);
+               showstatusmessage(txtLoadingError + ProfileDataAdapter.xhr.responseText);
                alert(ProfileDataAdapter.xhr.responseText);
                return;
             }
@@ -999,7 +1011,7 @@ InitMainForm = function()
             var records = ProfileDataAdapter.records;
             var length = records.length;
 
-            showstatusmessage("Processing profile");
+            showstatusmessage(txtProcessingProfile);
 
             for (var i = 0; i < length; i++)
             {
@@ -1018,17 +1030,17 @@ InitMainForm = function()
             showstatusmessage("Closing loader pop-up");
             $('#jqxLoader').jqxLoader('close');
             showstatusmessage("Showing error");
-            alert('Profile to edit not found');
+            alert(txtProfileToEditNot);
           }
           ,
           loadError: function (jqXHR, status, error)
           {
-            showstatusmessage("Loading error: "+error);
+            showstatusmessage(txtLoadingError+error);
             $('#jqxLoader').jqxLoader('close');
             if (error == "")
-               alert("Error. Connection with server might be lost.");
+               alert(txtErrorConnectionWithServerMightBeLost);
             else
-               alert("Profile Loading Error: "+error);
+               alert(txtProfileLoadingError+error);
            }
        });
 
@@ -1070,7 +1082,7 @@ InitMainForm = function()
            RefreshGrid();
           }
           else
-             alert( "Profile could not be modified: " + data);
+             alert( txtProfileCouldNotBeModified + data);
         });
             
     }
@@ -1096,7 +1108,7 @@ InitMainForm = function()
               RefreshGrid();
            }
            else
-              alert( "This was not possible: " + data);
+              alert( txtThisWasNotPossible + data);
         });
     }
  };
@@ -1124,7 +1136,7 @@ InitMainForm = function()
               RefreshGrid();
            }
            else
-              alert( "This was not possible: " + data);
+              alert( txtThisWasNotPossible + data);
         });
     }
  };
@@ -1147,7 +1159,7 @@ InitMainForm = function()
 
         $.post("post_diagnose_activity.php", json).done(function(data)
                {
-                alert("Please enable pop-ups, we will now try to open a new tab or window");
+                alert(txtPleaseEnablePopUpsWeWillNow);
                 window.open(data);
                }
            );
@@ -1194,11 +1206,96 @@ InitMainForm = function()
  function ExportProfiles()
  {
     window.open("exportprofiles.php?token="+GClientToken);
- };
+ }
+
  function ShowHelp()
  {
     window.open("help/help.html");
- };
+ }
+
+ let gLanguageMenuCreated = false;
+
+function createOrInitLanguageMenu()
+{
+   if (gLanguageMenuCreated) return;
+
+   // 1. Create container dynamically
+   const menuDiv = $('<div id="jqxLanguageMenu"></div>');
+
+   // 2. Menu structure
+   const ul = $('<ul class="two-columns"></ul>');
+   Glanguages.forEach(lang => {
+       ul.append('<li>' + lang + '</li>');
+   });
+   menuDiv.append(ul);
+
+   // 3. Add to DOM, but keep hidden initially
+   $('body').append(menuDiv);
+   menuDiv.hide();
+
+   // 4. Initialize jqxMenu
+   menuDiv.jqxMenu({
+       width: '400px',
+       autoOpenPopup: false,
+       mode: 'popup'
+   });
+
+   menuDiv.on('itemclick', function (event) {
+     $("#jqxLanguageMenu").hide();
+
+     // jqxMenu gives the clicked LI in event.args
+     var language = $(event.args).text().trim();
+
+     var sendparams = {
+         token: GClientToken,
+         language: language
+     };
+
+   $.post("post_language.php", JSON.stringify(sendparams))
+       .done(function (data) {
+           // Force reload and bypass cache
+           window.location.reload(true);
+       })
+       .fail(function (xhr) {
+           alert("Error saving language: " + xhr);
+       });
+   });
+
+   gLanguageMenuCreated = true;
+}
+
+
+// ------------------------------------------------------------
+// Show the menu next to #language_button
+// ------------------------------------------------------------
+function showLanguageMenu() {
+    createOrInitLanguageMenu(); // safe to call every time
+
+    const menu = $("#jqxLanguageMenu");
+    const btn = $("#language_button");
+
+    // Get screen position of the button
+    const offset = btn.offset();
+    const btnHeight = btn.outerHeight();
+
+    // Position menu below the button
+    menu.css({
+        position: "absolute",
+        left: offset.left,
+        top: offset.top + btnHeight + 2,
+        zIndex: 99999,
+        display: "block"
+    });
+
+    // jqxMenu requires "open" with left/top parameters
+    menu.jqxMenu('open', offset.left, offset.top + btnHeight + 2);
+}
+
+
+ function ChooseLanguage()
+ {
+   showLanguageMenu();
+ }
 
  function PerformLogout()
  {
@@ -1235,7 +1332,7 @@ InitMainForm = function()
               $("#LogFilesDlg_div").html(LogFilesDlgHTML);
 
                  $('#jqxLogFilesDlg').jqxWindow({ maxWidth: 900,  width:900, maxHeight:650, height:650, autoOpen: false, isModal: true,
-                     theme: GTheme, animationType: 'slide', closeButtonAction: 'close' });
+                     theme: GTheme, animationType: 'none', closeButtonAction: 'close' });
 
 
                   var GridSource =
@@ -1275,7 +1372,7 @@ InitMainForm = function()
                   columns: [
 
                     { text: ' ', datafield: 'id', width: 50 },
-                    { text: 'Log File', datafield: 'LogFileName', width: 800 }                                  ]
+                    { text: txtLogFile, datafield: 'LogFileName', width: 800 }                                  ]
 
                 });
 
@@ -1306,7 +1403,7 @@ InitMainForm = function()
 
  function TerminateProcess()
  {
-    if (confirm('Web server process will be terminated. Are you sure ?'))
+    if (confirm(txtWebServerProcessWillBeTerminatedAre))
     {
         var sendparams = { };
         sendparams.token = GClientToken;
@@ -1315,7 +1412,7 @@ InitMainForm = function()
         {
            if (data != '')
            {
-              alert("Termination of syncovery web server process info: "   + data);
+              alert(txtTerminationOfSyncoveryWebServerProcessInfo   + data);
            }
                                   
         });
